<?php

namespace Lavalite\Litecms\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Lavalite\Litecms\Http\Requests\ShoppingRequest;
use Lavalite\Litecms\Interfaces\ShoppingRepositoryInterface;
use Lavalite\Litecms\Models\Shopping;

/**
 * Resource controller class for shopping.
 */
class ShoppingResourceController extends BaseController
{

    /**
     * Initialize shopping resource controller.
     *
     * @param type ShoppingRepositoryInterface $shopping
     *
     * @return null
     */
    public function __construct(ShoppingRepositoryInterface $shopping)
    {
        parent::__construct();
        $this->repository = $shopping;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Lavalite\Litecms\Repositories\Criteria\ShoppingResourceCriteria::class);
    }

    /**
     * Display a list of shopping.
     *
     * @return Response
     */
    public function index(ShoppingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Lavalite\Litecms\Repositories\Presenter\ShoppingPresenter::class)
                ->$function();
        }

        $shoppings = $this->repository->paginate();

        return $this->response->title(trans('litecms::shopping.names'))
            ->view('litecms::shopping.index', true)
            ->data(compact('shoppings'))
            ->output();
    }

    /**
     * Display shopping.
     *
     * @param Request $request
     * @param Model   $shopping
     *
     * @return Response
     */
    public function show(ShoppingRequest $request, Shopping $shopping)
    {

        if ($shopping->exists) {
            $view = 'litecms::shopping.show';
        } else {
            $view = 'litecms::shopping.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('litecms::shopping.name'))
            ->data(compact('shopping'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new shopping.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ShoppingRequest $request)
    {

        $shopping = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('litecms::shopping.name')) 
            ->view('litecms::shopping.create', true) 
            ->data(compact('shopping'))
            ->output();
    }

    /**
     * Create new shopping.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ShoppingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $shopping                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('litecms::shopping.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('litecms/shopping/' . $shopping->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/litecms/shopping'))
                ->redirect();
        }

    }

    /**
     * Show shopping for editing.
     *
     * @param Request $request
     * @param Model   $shopping
     *
     * @return Response
     */
    public function edit(ShoppingRequest $request, Shopping $shopping)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('litecms::shopping.name'))
            ->view('litecms::shopping.edit', true)
            ->data(compact('shopping'))
            ->output();
    }

    /**
     * Update the shopping.
     *
     * @param Request $request
     * @param Model   $shopping
     *
     * @return Response
     */
    public function update(ShoppingRequest $request, Shopping $shopping)
    {
        try {
            $attributes = $request->all();

            $shopping->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('litecms::shopping.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('litecms/shopping/' . $shopping->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('litecms/shopping/' . $shopping->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the shopping.
     *
     * @param Model   $shopping
     *
     * @return Response
     */
    public function destroy(ShoppingRequest $request, Shopping $shopping)
    {
        try {

            $shopping->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('litecms::shopping.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('litecms/shopping/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('litecms/shopping/' . $shopping->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple shopping.
     *
     * @param Model   $shopping
     *
     * @return Response
     */
    public function delete(ShoppingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('litecms::shopping.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('litecms/shopping'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/litecms/shopping'))
                ->redirect();
        }

    }

    /**
     * Restore deleted shoppings.
     *
     * @param Model   $shopping
     *
     * @return Response
     */
    public function restore(ShoppingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('litecms::shopping.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/litecms/shopping'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/litecms/shopping/'))
                ->redirect();
        }

    }

}
